@@ -749,8 +749,7 @@ class FilterGeneration(DARMModel):
         self.calcs = CALCSModel(config)
 
         # Parameters directly from IFO params file
-        self.arm_length = np.mean(np.array([self.darm.sensing.x_arm_length,
-                                            self.darm.sensing.y_arm_length]))
+        self.arm_length = self.darm.sensing.mean_arm_length()
         self.fcc = self.darm.sensing.coupled_cavity_pole_frequency
         self.fs = self.darm.sensing.detuned_spring_frequency
         self.fs_squared = np.real(pow(self.fs, 2.0))
