@@ -707,15 +707,153 @@ class DARMActuationModel(Model):
         """
 
         output_matrix = np.zeros((2, 4))
-        for n in range(len(output_matrix[:, 0])):
-            for m in range(len(output_matrix[0, :])):
-                if n == 0 and self.darm_feedback_x[m] == 'ON':
-                    output_matrix[n, m] = self.darm_output_matrix[0]
-                elif n == 1 and self.darm_feedback_y[m] == 'ON':
-                    output_matrix[n, m] = self.darm_output_matrix[1]
+        for m in range(len(output_matrix[:, 0])):
+            for n in range(len(output_matrix[0, :])):
+                if m == 0 and self.darm_feedback_x[n] == 'ON':
+                    output_matrix[m, n] = self.darm_output_matrix[0]
+                elif m == 1 and self.darm_feedback_y[n] == 'ON':
+                    output_matrix[m, n] = self.darm_output_matrix[1]
 
         return output_matrix
 
+    def stage_super_actuator(self, frequencies, stage='TST', syserr_dict=None):
+        """
+        Compute the super actuator transfer function for a specific stage.
+        In this case, the "stage super actuator" is created by choosing a
+        specific stage and then for each QUAD, the stage transfer function to
+        DARM is summed together.
+
+        This transfer function is from DARM_CTRL to meters sensed by the IFO.
+        Note that the sign of the DARM_ERR signal is dependent upon which arm
+        is under control.
+
+        The OMC to SUS delay is included in this transfer function.
+
+        Parameters
+        ----------
+        frequencies : `float`, array-like
+            array of frequencies to compute the response
+        stage : `str`
+            SUS stage for the calculation, 'UIM', 'PUM', or 'TST'
+        syserr_dict : `dict`, optional
+            dict of multiplicative values, ex.:
+            {'xarm': {'UIM': `complex`, array-like}}
+
+        Returns
+        -------
+        super_actuation : `complex128`, array-like
+            transfer function response of the actuation function
+        """
+
+        output_matrix = self.darm_output_matrix_values()
+
+        super_actuation = np.zeros(len(frequencies), dtype='complex128')
+
+        stage_idx = ['top', 'uim', 'pum', 'tst'].index(stage.lower())
+        for arm_idx, arm in enumerate(['x', 'y']):
+            if output_matrix[arm_idx, stage_idx] != 0.0:
+                assert stage_idx > 0, 'top has not been implemented'
+
+                if hasattr(self, f'{arm}arm') is False:
+                    raise ValueError(
+                        'Must provide an ActuationModel object')
+                else:
+                    this_arm = getattr(self, f'{arm}arm')
+
+                single_stage = this_arm.compute_actuation_single_stage(
+                        frequencies, stage=stage.upper())
+
+                if (syserr_dict is not None and
+                        ['xarm', 'yarm'][arm_idx] in syserr_dict and
+                        stage.upper() in syserr_dict[['xarm', 'yarm'][arm_idx]]):
+                    single_stage *= (
+                        syserr_dict[['xarm', 'yarm'][arm_idx]][stage.upper()])
+
+                super_actuation += (
+                    output_matrix[arm_idx, stage_idx] * single_stage)
+
+        # OMC to SUS model jump delay, sending DARM_CTRL from the omc
+        # front-end model via IPC to any QUAD SUS model, identical for any
+        # QUAD, either at the corner or end.
+        # Note that SUS to IOP, IOP to analog, and unknown delays have already
+        # been applied in compute_actuation_single_stage.
+        # For measurement confirmation of computational time delays see
+        # G1601472.
+        omc_to_sus_delay_response = signal.dfreqresp(
+            digital_delay_filter(1, 16384), 2.0*np.pi*frequencies/16384)[1]
+        super_actuation *= omc_to_sus_delay_response
+
+        return super_actuation
+
+    def arm_super_actuator(self, frequencies, arm='x', syserr_dict=None):
+        """
+        Compute the super actuator transfer function for a specific arm.
+        In this case, the "arm super actuator" is created by choosing a
+        specific arm and then for each QUAD, the arm transfer function to
+        DARM is summed together.
+
+        This transfer function is from DARM_CTRL to meters sensed by the IFO.
+        Note that the sign of the DARM_ERR signal is dependent upon which arm
+        is under control.
+
+        The OMC to SUS delay is included in this transfer function.
+
+        Parameters
+        ----------
+        frequencies : `float`, array-like
+            array of frequencies to compute the response
+        arm : `str`
+            arm for the calculation, 'x' or 'y'
+        actuation_syserr_dict : `dict`, optional
+            dict of multiplicative values, ex.:
+            {'xarm': {'UIM': `complex`, array-like}}
+
+        Returns
+        -------
+        super_actuation : `complex128`, array-like
+            transfer function response of the actuation function
+        """
+
+        output_matrix = self.darm_output_matrix_values()
+
+        super_actuation = np.zeros(len(frequencies), dtype='complex128')
+
+        arm_idx = ['x', 'y'].index(arm.lower())
+        for stage_idx, stage in enumerate(['top', 'uim', 'pum', 'tst']):
+            if output_matrix[arm_idx, stage_idx] != 0.0:
+                assert stage_idx > 0, 'top has not been implemented'
+
+                if hasattr(self, f'{arm}arm') is False:
+                    raise ValueError(
+                        'Must provide an ActuationModel object')
+                else:
+                    this_arm = getattr(self, f'{arm}arm')
+
+                single_stage = this_arm.compute_actuation_single_stage(
+                        frequencies, stage=stage.upper())
+
+                if (syserr_dict is not None and
+                        ['xarm', 'yarm'][arm_idx] in syserr_dict and
+                        stage.label() in syserr_dict[['xarm', 'yarm'][arm_idx]]):
+                    single_stage *= (
+                        syserr_dict[['xarm', 'yarm'][arm_idx]][stage.upper()])
+
+                super_actuation += (
+                    output_matrix[arm_idx, stage_idx] * single_stage)
+
+        # OMC to SUS model jump delay, sending DARM_CTRL from the omc
+        # front-end model via IPC to any QUAD SUS model, identical for any
+        # QUAD, either at the corner or end.
+        # Note that SUS to IOP, IOP to analog, and unknown delays have already
+        # been applied in compute_actuation_single_stage.
+        # For measurement confirmation of computational time delays see
+        # G1601472.
+        omc_to_sus_delay_response = signal.dfreqresp(
+            digital_delay_filter(1, 16384), 2.0*np.pi*frequencies/16384)[1]
+        super_actuation *= omc_to_sus_delay_response
+
+        return super_actuation
+
     def compute_actuation(self, frequencies, syserr_dict=None):
         """
         Compute the entire actuation function transfer function (see G1501518).
@@ -737,50 +875,11 @@ class DARMActuationModel(Model):
             transfer function response of the actuation function
         """
 
-        output_matrix = self.darm_output_matrix_values()
-
         darm_actuation = np.zeros(len(frequencies), dtype='complex128')
-        for arm in range(len(output_matrix[:, 0])):
-            for stage in range(len(output_matrix[0, :])):
-                if output_matrix[arm, stage] != 0.0:
-                    if stage == 0:
-                        stage_label = 'TOP'
-                    elif stage == 1:
-                        stage_label = 'UIM'
-                    elif stage == 2:
-                        stage_label = 'PUM'
-                    else:
-                        stage_label = 'TST'
-                    if arm == 0:
-                        if self.xarm is None:
-                            raise ValueError(
-                                'Must provide an xarm ActuationModel object')
-                        this_arm = self.xarm
-                    else:
-                        if self.yarm is None:
-                            raise ValueError(
-                                'Must provide a yarm ActuationModel object')
-                        this_arm = self.yarm
-                    single_stage = this_arm.compute_actuation_single_stage(
-                        frequencies, stage=stage_label)
 
-                    if (syserr_dict is not None and
-                       ['xarm', 'yarm'][arm] in syserr_dict and
-                       stage_label in syserr_dict[['xarm', 'yarm'][arm]]):
-                        single_stage *= \
-                            syserr_dict[['xarm', 'yarm'][arm]][stage_label]
-
-                    darm_actuation += output_matrix[arm, stage] * single_stage
-
-        # OMC to SUS model jump delay, sending DARM_CTRL from the omc
-        # front-end model via IPC to any QUAD SUS model, identical for any
-        # QUAD, either at the corner or end.
-        # Note that SUS to IOP, IOP to analog, and unknown delays have already
-        # been applied in compute_actuation_single_stage.
-        # For measurement confirmation of computational time delays see
-        # G1601472.
-        omc_to_sus_delay_response = signal.dfreqresp(
-            digital_delay_filter(1, 16384), 2.0*np.pi*frequencies/16384)[1]
-        darm_actuation *= omc_to_sus_delay_response
+        # This has the OMC to SUS time delay
+        for stage_idx, stage in enumerate(['top', 'uim', 'pum', 'tst']):
+            darm_actuation += self.stage_super_actuator(
+                frequencies, stage=stage.upper(), syserr_dict=syserr_dict)
 
         return darm_actuation
