@@ -335,9 +335,8 @@ class CALCSModel(DARMModel):
         """
         A_n,calcs
 
-        CALCS approximation of a specific arm, stage from DARM_CTRL
-        input to SUS ISCINF to DARM (and therefore does not include
-        the OMC to CALCS delay)
+        CALCS approximation of a specific arm, stage from input to SUS ISCINF
+        to DARM (and therefore does not include the OMC to CALCS delay)
         displacement. See T1900169
 
 
@@ -382,6 +381,91 @@ class CALCSModel(DARMModel):
 
         return calcs_stage_actuation
 
+    def stage_super_actuator(self, frequencies, stage='TST'):
+        """
+        Compute the super actuator transfer function for a specific stage as
+        estimated by the CALCS model.
+        In this case, the "stage super actuator" is created by choosing a
+        specific stage and then for each QUAD, the stage transfer function to
+        DARM is summed together.
+
+        This transfer function is from DARM_CTRL to meters sensed by the IFO.
+        Note that the sign of the DARM_ERR signal is dependent upon which arm
+        is under control.
+
+        Parameters
+        ----------
+        frequencies : `float`, array-like
+            array of frequencies to compute the response
+        stage : `str`
+            SUS stage for the calculation, 'UIM', 'PUM', or 'TST'
+
+        Returns
+        -------
+        tf : `complex128`, array-like
+            transfer function response of the actuation function
+        """
+
+        # Assume the same as in-loop DARM output matrix
+        output_matrix = self.actuation.darm_output_matrix_values()
+
+        super_actuation = np.zeros(len(frequencies), dtype='complex128')
+
+        stage_idx = ['top', 'uim', 'pum', 'tst'].index(stage.lower())
+        for arm_idx, arm in enumerate(['x', 'y']):
+            if output_matrix[arm_idx, stage_idx] != 0.0:
+                assert stage_idx > 0, 'top has not been implemented'
+
+                single_stage = self.compute_actuation_single_stage(
+                        frequencies, arm=arm, stage=stage.upper())
+
+                super_actuation += (
+                    output_matrix[arm_idx, stage_idx] * single_stage)
+
+        return super_actuation
+
+    def arm_super_actuator(self, frequencies, arm='x'):
+        """
+        Compute the super actuator transfer function for a specific arm.
+        In this case, the "arm super actuator" is created by choosing a
+        specific arm and then for each QUAD, the arm transfer function to
+        DARM is summed together.
+
+        This transfer function is from DARM_CTRL to meters sensed by the IFO.
+        Note that the sign of the DARM_ERR signal is dependent upon which arm
+        is under control.
+
+        Parameters
+        ----------
+        frequencies : `float`, array-like
+            array of frequencies to compute the response
+        stage : `str`
+            SUS stage for the calculation, 'UIM', 'PUM', or 'TST'
+
+        Returns
+        -------
+        super_actuation : `complex128`, array-like
+            transfer function response of the actuation function
+        """
+
+        # Assume the same as in-loop DARM output matrix
+        output_matrix = self.actuation.darm_output_matrix_values()
+
+        super_actuation = np.zeros(len(frequencies), dtype='complex128')
+
+        arm_idx = ['x', 'y'].index(arm.lower())
+        for stage_idx, stage in enumerate(['top', 'uim', 'pum', 'tst']):
+            if output_matrix[arm_idx, stage_idx] != 0.0:
+                assert stage_idx > 0, 'top has not been implemented'
+
+                single_stage = self.compute_actuation_single_stage(
+                        frequencies, arm=arm, stage=stage.upper())
+
+                super_actuation += (
+                    output_matrix[arm_idx, stage_idx] * single_stage)
+
+        return super_actuation
+
     def gds_actuation_correction(self, frequencies, stage, daqdownsample=True):
         """
         Compute the correction to the CAL-CS output for GDS. Note that this
@@ -416,39 +500,21 @@ class CALCSModel(DARMModel):
             transfer function response of the correction
         """
 
-        # Assume the same as in-loop DARM output matrix
-        output_matrix = self.actuation.darm_output_matrix_values()
+        # ideal model sum of actuators for A_{xn} and A_{yn}
+        # this DOES NOT include the OMC to SUS delay
+        A_n = self.actuation.stage_super_actuator(frequencies,
+                                                  stage=stage.upper())
 
-        # 1 clock cycle delay transfer function for OMC to SUS and
-        # OMC to CALCS
-        omc_to_sus_response = (
-            signal.dfreqresp(digital_delay_filter(1, 16384),
-                             2.0*np.pi*frequencies/16384)[1])
+        # CALCS approximate for A_{xn,calcs} and A_{yn,calcs}
+        # this DOES include the OMC to CALCS delay
+        A_n_calcs = self.stage_super_actuator(frequencies,
+                                              stage=stage.upper())
+
+        # 1 clock cycle delay transfer function for OMC to CALCS
         omc_to_calcs_response = (
             signal.dfreqresp(digital_delay_filter(1, 16384),
                              2.0*np.pi*frequencies/16384)[1])
 
-        A_n = 0
-        A_n_calcs = 0
-        stage_idx = ['top', 'uim', 'pum', 'tst'].index(stage.lower())
-        for arm_idx, arm in enumerate(['x', 'y']):
-            if (output_matrix[arm_idx, stage_idx] != 0.0):
-                assert stage_idx > 0, 'top has not been implemented'
-
-                arm_obj = getattr(self.actuation, f'{arm}arm')
-
-                # ideal model sum of actuators for A_{xn} and A_{yn}
-                A_n += (
-                    output_matrix[arm_idx, stage_idx] *
-                    arm_obj.compute_actuation_single_stage(
-                        frequencies, stage=stage))
-
-                # CALCS approximate for A_{xn,calcs} and A_{yn,calcs}
-                A_n_calcs += (
-                    output_matrix[arm_idx, stage_idx] *
-                    self.compute_actuation_single_stage(
-                        frequencies, arm=arm, stage=stage))
-
         if daqdownsample:
             # DAQ downsampling filters are applied so we need to account
             # for this
@@ -459,7 +525,8 @@ class CALCSModel(DARMModel):
             daqdownsampling = 1
 
         # This is \delta A_n
-        correction = ((omc_to_sus_response * A_n / A_n_calcs) *
+        # note that A_n already includes the OMC to SUS response
+        correction = ((A_n / A_n_calcs) *
                       (1 / (daqdownsampling * omc_to_calcs_response)))
 
         return correction
@@ -484,26 +551,13 @@ class CALCSModel(DARMModel):
             Residual phase after removing the simulated delay
         """
 
-        # Assume the same as in-loop DARM output matrix
-        # we won't actually multiply these values it's just to help
-        # loop through stages that are used
-        output_matrix = self.actuation.darm_output_matrix_values()
-
         # Start with zeros
         calcs_actuation = np.zeros(len(frequencies), dtype='complex128')
 
-        # Loop over arms and stages to compute the digital filters and scale/sum
-        # everything together
-        # output matrix * digital filters * calcs digital out to displacement
-        for arm_idx, arm in enumerate(['x', 'y']):
-            for stage_idx, stage in enumerate(['top', 'uim', 'pum', 'tst']):
-                if output_matrix[arm_idx, stage_idx] != 0.0:
-                    assert stage_idx > 0, 'top has not been implemented'
-                    # dig_filt only has UIM, PUM, and TST
-                    # calcs_dig_out_to_disp has same order as output_matrix
-                    calcs_actuation += (
-                        self.compute_actuation_single_stage(
-                            frequencies, arm=arm, stage=stage))
+        # This has the OMC to CALCS time delay
+        for stage_idx, stage in enumerate(['top', 'uim', 'pum', 'tst']):
+            calcs_actuation += self.stage_super_actuator(
+                frequencies, stage=stage.upper())
 
         return calcs_actuation
 
@@ -719,8 +773,7 @@ class CALCSModel(DARMModel):
                   (1.0 + G*delay_interp/(C_corr*A_corr))))
 
         if strain_calib:
-            calib /= np.mean(np.array([self.sensing.x_arm_length,
-                                       self.sensing.y_arm_length]))
+            calib /= self.sensing.mean_arm_length()
 
         # Save to file and use the fmt options if given
         # default is to save as dB magnitude and degrees phase
@@ -749,3 +802,31 @@ class CALCSModel(DARMModel):
                        fmt='%.7g')
 
         return calib
+
+    def deltal_ext_pcal_corrrection(self, frequencies, **kwargs):
+        """
+        Compute the calibration transfer function, dL_pyDARM / dL_Pcal
+        for determining the response function systematic error
+
+        See T1900169 section V
+
+        Parameters
+        ----------
+        frequencies : `float`, array-like
+            array of frequencies to compute the CAL_DELTAL_EXTERNAL DTT
+            calibration
+        kwargs : optional
+            values are passed to `calcs.calcs_dtt_calibration()`
+
+        Returns
+        -------
+        tf : `complex128`, array-like
+            transfer function resposne of the correction factor
+        """
+
+        deltal_ext = self.calcs_dtt_calibration(frequencies, kwargs)
+        pcal_corr = self.pcal.compute_pcal_correction(frequencies)
+
+        tf = deltal_ext / pcal_corr
+
+        return tf
