@@ -139,7 +139,7 @@ class DARMModel(Model):
         return (1.0/C_response + D_response * A_response)
 
     def compute_epics_records(self, f_pcal1, f_uim, f_pum, f_tst, f_pcal2,
-                              f_pcal3, f_pcal4, arm, save_to_file=None,
+                              f_pcal3, arm, save_to_file=None,
                               endstation=False):
         """
         This is a LIGO specific function for generating front end calibration
@@ -164,8 +164,6 @@ class DARMModel(Model):
             Pcal line frequency 2 (the mid-frequency ~400 Hz line)
         f_pcal3 : `float`
             Pcal line frequency 3 (the high-frequency ~1080 Hz line)
-        f_pcal4 : `float`
-            Pcal line frequency 4 (the low frequency ~8 Hz line)
         arm : `str`
             'x' or 'y' to indicate which arm is used for the SUS actuators
         save_to_file : `str`, optional
@@ -185,7 +183,7 @@ class DARMModel(Model):
         """
 
         freq = np.array(
-            [f_pcal1, f_uim, f_pum, f_tst, f_pcal2, f_pcal3, f_pcal4])
+            [f_pcal1, f_uim, f_pum, f_tst, f_pcal2, f_pcal3])
 
         R = self.compute_response_function(freq)
 
@@ -197,13 +195,11 @@ class DARMModel(Model):
         # See T1700106
         pcal_correction = self.pcal.compute_pcal_correction(freq, endstation)
         PCAL_LINE1_CORRECTION = (
-            pcal_correction[0] * np.exp(-2*np.pi*1j*freq[0]/16384))   # EP0
+            pcal_correction[0] * np.exp(-2*np.pi*1j*freq[0]/16384))
         PCAL_LINE2_CORRECTION = (
-            pcal_correction[4] * np.exp(-2*np.pi*1j*freq[4]/16384))   # EP9
+            pcal_correction[4] * np.exp(-2*np.pi*1j*freq[4]/16384))
         PCAL_LINE3_CORRECTION = (
-            pcal_correction[5] * np.exp(-2*np.pi*1j*freq[5]/16384))   # EP24
-        PCAL_LINE4_CORRECTION = (
-            pcal_correction[6] * np.exp(-2*np.pi*1j*freq[6]/16384))   # EP15
+            pcal_correction[5] * np.exp(-2*np.pi*1j*freq[5]/16384))
 
         # The actuator lines are injected at the input to the DRIVEALIGN bank
         # Also get the complete actuation model
@@ -235,25 +231,13 @@ class DARMModel(Model):
         # See T1700106
         SUS_LINE1_REF_INVA_UIM_RESPRATIO = (
             (1.0/(uim_actuation_epics[1]/daqdownsampling_response[1])) *
-            (1.0/R[0]) * R[1] * np.exp(2*np.pi*1j*freq[1]/16384))  # EP3
+            (1.0/R[0]) * R[1] * np.exp(2*np.pi*1j*freq[1]/16384))
         SUS_LINE2_REF_INVA_PUM_RESPRATIO = (
             (1.0/(pum_actuation_epics[2]/daqdownsampling_response[2])) *
-            (1.0/R[0]) * R[2] * np.exp(2*np.pi*1j*freq[2]/16384))  # EP2
+            (1.0/R[0]) * R[2] * np.exp(2*np.pi*1j*freq[2]/16384))
         SUS_LINE3_REF_INVA_TST_RESPRATIO = (
             (1.0/(tst_actuation_epics[3]/daqdownsampling_response[3])) *
-            (1.0/R[0]) * R[3] * np.exp(2*np.pi*1j*freq[3]/16384))  # EP1
-
-        # Need to add a phase delay to the PCAL readback because the
-        # PCAL channel acquires a phase delay from the model jump
-        # to CAL-CS and the calculation expects no delay (as in GDS)
-        PCAL_LINE1_PCAL_DEMOD_PHASE = (
-            np.angle(np.exp(-2*np.pi*1j*freq[0]/16384), deg=True))
-        PCAL_LINE2_PCAL_DEMOD_PHASE = (
-            np.angle(np.exp(-2*np.pi*1j*freq[4]/16384), deg=True))
-        PCAL_LINE3_PCAL_DEMOD_PHASE = (
-            np.angle(np.exp(-2*np.pi*1j*freq[5]/16384), deg=True))
-        PCAL_LINE4_PCAL_DEMOD_PHASE = (
-            np.angle(np.exp(-2*np.pi*1j*freq[6]/16384), deg=True))
+            (1.0/R[0]) * R[3] * np.exp(2*np.pi*1j*freq[3]/16384))
 
         # Need to add a phase delay to the SUS excitation because the
         # SUS channel acquires a phase delay from the model jump
@@ -277,26 +261,21 @@ class DARMModel(Model):
         sensing_no_cavity_response = (
             self.sensing.compute_sensing(freq) /
             signal.freqresp(coupled_cavity, 2.0*np.pi*freq)[1])
-        PCAL_LINE2_REF_C_NOCAVPOLE = sensing_no_cavity_response[4]  # EP4
-        PCAL_LINE4_REF_C_NOCAVPOLE = sensing_no_cavity_response[6]  # EP10
-        PCAL_LINE1_REF_C_NOCAVPOLE = sensing_no_cavity_response[0]  # EP19
+        PCAL_LINE2_REF_C_NOCAVPOLE = sensing_no_cavity_response[4]
+        PCAL_LINE1_REF_C_NOCAVPOLE = sensing_no_cavity_response[0]
 
         # DARM digital filtering
         darm_digital_filter_response = self.digital.compute_response(freq)
-        PCAL_LINE2_REF_D = darm_digital_filter_response[4]  # EP5
-        PCAL_LINE4_REF_D = darm_digital_filter_response[6]  # EP11
-        PCAL_LINE1_REF_D = darm_digital_filter_response[0]  # EP20
+        PCAL_LINE2_REF_D = darm_digital_filter_response[4]
+        PCAL_LINE1_REF_D = darm_digital_filter_response[0]
 
         # Actuation
-        PCAL_LINE2_REF_A_TST = tst[4]  # EP6
-        PCAL_LINE2_REF_A_PUM = pum[4]  # EP7
-        PCAL_LINE2_REF_A_UIM = uim[4]  # EP8
-        PCAL_LINE4_REF_A_TST = tst[6]  # EP12
-        PCAL_LINE4_REF_A_PUM = pum[6]  # EP13
-        PCAL_LINE4_REF_A_UIM = uim[6]  # EP14
-        PCAL_LINE1_REF_A_TST = tst[0]  # EP21
-        PCAL_LINE1_REF_A_PUM = pum[0]  # EP22
-        PCAL_LINE1_REF_A_UIM = uim[0]  # EP23
+        PCAL_LINE2_REF_A_TST = tst[4]
+        PCAL_LINE2_REF_A_PUM = pum[4]
+        PCAL_LINE2_REF_A_UIM = uim[4]
+        PCAL_LINE1_REF_A_TST = tst[0]
+        PCAL_LINE1_REF_A_PUM = pum[0]
+        PCAL_LINE1_REF_A_UIM = uim[0]
 
         if save_to_file is not None:
             save_txt_epcis_value = np.vstack(
@@ -320,18 +299,6 @@ class DARMModel(Model):
                  PCAL_LINE2_REF_A_UIM.imag,
                  PCAL_LINE2_CORRECTION.real,
                  PCAL_LINE2_CORRECTION.imag,
-                 PCAL_LINE4_REF_C_NOCAVPOLE.real,
-                 PCAL_LINE4_REF_C_NOCAVPOLE.imag,
-                 PCAL_LINE4_REF_D.real,
-                 PCAL_LINE4_REF_D.imag,
-                 PCAL_LINE4_REF_A_TST.real,
-                 PCAL_LINE4_REF_A_TST.imag,
-                 PCAL_LINE4_REF_A_PUM.real,
-                 PCAL_LINE4_REF_A_PUM.imag,
-                 PCAL_LINE4_REF_A_UIM.real,
-                 PCAL_LINE4_REF_A_UIM.imag,
-                 PCAL_LINE4_CORRECTION.real,
-                 PCAL_LINE4_CORRECTION.imag,
                  PCAL_LINE1_REF_C_NOCAVPOLE.real,
                  PCAL_LINE1_REF_C_NOCAVPOLE.imag,
                  PCAL_LINE1_REF_D.real,
@@ -344,10 +311,6 @@ class DARMModel(Model):
                  PCAL_LINE1_REF_A_UIM.imag,
                  PCAL_LINE3_CORRECTION.real,
                  PCAL_LINE3_CORRECTION.imag,
-                 PCAL_LINE1_PCAL_DEMOD_PHASE,
-                 PCAL_LINE2_PCAL_DEMOD_PHASE,
-                 PCAL_LINE3_PCAL_DEMOD_PHASE,
-                 PCAL_LINE4_PCAL_DEMOD_PHASE,
                  SUS_LINE1_SUS_DEMOD_PHASE,
                  SUS_LINE2_SUS_DEMOD_PHASE,
                  SUS_LINE3_SUS_DEMOD_PHASE))
@@ -373,18 +336,6 @@ class DARMModel(Model):
                  'CAL-CS_TDEP_PCAL_LINE2_REF_A_UIM_IMAG',
                  'CAL-CS_TDEP_PCAL_LINE2_CORRECTION_REAL',
                  'CAL-CS_TDEP_PCAL_LINE2_CORRECTION_IMAG',
-                 'CAL-CS_TDEP_PCAL_LINE4_REF_C_NOCAVPOLE_REAL',
-                 'CAL-CS_TDEP_PCAL_LINE4_REF_C_NOCAVPOLE_IMAG',
-                 'CAL-CS_TDEP_PCAL_LINE4_REF_D_REAL',
-                 'CAL-CS_TDEP_PCAL_LINE4_REF_D_IMAG',
-                 'CAL-CS_TDEP_PCAL_LINE4_REF_A_TST_REAL',
-                 'CAL-CS_TDEP_PCAL_LINE4_REF_A_TST_IMAG',
-                 'CAL-CS_TDEP_PCAL_LINE4_REF_A_PUM_REAL',
-                 'CAL-CS_TDEP_PCAL_LINE4_REF_A_PUM_IMAG',
-                 'CAL-CS_TDEP_PCAL_LINE4_REF_A_UIM_REAL',
-                 'CAL-CS_TDEP_PCAL_LINE4_REF_A_UIM_IMAG',
-                 'CAL-CS_TDEP_PCAL_LINE4_CORRECTION_REAL',
-                 'CAL-CS_TDEP_PCAL_LINE4_CORRECTION_IMAG',
                  'CAL-CS_TDEP_PCAL_LINE1_REF_C_NOCAVPOLE_REAL',
                  'CAL-CS_TDEP_PCAL_LINE1_REF_C_NOCAVPOLE_IMAG',
                  'CAL-CS_TDEP_PCAL_LINE1_REF_D_REAL',
@@ -397,10 +348,6 @@ class DARMModel(Model):
                  'CAL-CS_TDEP_PCAL_LINE1_REF_A_UIM_IMAG',
                  'CAL-CS_TDEP_PCAL_LINE3_CORRECTION_REAL',
                  'CAL-CS_TDEP_PCAL_LINE3_CORRECTION_IMAG',
-                 'CAL-CS_TDEP_PCAL_LINE1_PCAL_DEMOD_PHASE',
-                 'CAL-CS_TDEP_PCAL_LINE2_PCAL_DEMOD_PHASE',
-                 'CAL-CS_TDEP_PCAL_LINE3_PCAL_DEMOD_PHASE',
-                 'CAL-CS_TDEP_PCAL_LINE4_PCAL_DEMOD_PHASE',
                  'CAL-CS_TDEP_SUS_LINE1_SUS_DEMOD_PHASE',
                  'CAL-CS_TDEP_SUS_LINE2_SUS_DEMOD_PHASE',
                  'CAL-CS_TDEP_SUS_LINE3_SUS_DEMOD_PHASE'))
@@ -430,22 +377,12 @@ class DARMModel(Model):
             'CAL-CS_TDEP_PCAL_LINE2_REF_A_PUM': PCAL_LINE2_REF_A_PUM,
             'CAL-CS_TDEP_PCAL_LINE2_REF_A_UIM': PCAL_LINE2_REF_A_UIM,
             'CAL-CS_TDEP_PCAL_LINE2_CORRECTION': PCAL_LINE2_CORRECTION,
-            'CAL-CS_TDEP_PCAL_LINE4_REF_C_NOCAVPOLE': PCAL_LINE4_REF_C_NOCAVPOLE,
-            'CAL-CS_TDEP_PCAL_LINE4_REF_D': PCAL_LINE4_REF_D,
-            'CAL-CS_TDEP_PCAL_LINE4_REF_A_TST': PCAL_LINE4_REF_A_TST,
-            'CAL-CS_TDEP_PCAL_LINE4_REF_A_PUM': PCAL_LINE4_REF_A_PUM,
-            'CAL-CS_TDEP_PCAL_LINE4_REF_A_UIM': PCAL_LINE4_REF_A_UIM,
-            'CAL-CS_TDEP_PCAL_LINE4_CORRECTION': PCAL_LINE4_CORRECTION,
             'CAL-CS_TDEP_PCAL_LINE1_REF_C_NOCAVPOLE': PCAL_LINE1_REF_C_NOCAVPOLE,
             'CAL-CS_TDEP_PCAL_LINE1_REF_D': PCAL_LINE1_REF_D,
             'CAL-CS_TDEP_PCAL_LINE1_REF_A_TST': PCAL_LINE1_REF_A_TST,
             'CAL-CS_TDEP_PCAL_LINE1_REF_A_PUM': PCAL_LINE1_REF_A_PUM,
             'CAL-CS_TDEP_PCAL_LINE1_REF_A_UIM': PCAL_LINE1_REF_A_UIM,
             'CAL-CS_TDEP_PCAL_LINE3_CORRECTION': PCAL_LINE3_CORRECTION,
-            'CAL-CS_TDEP_PCAL_LINE1_PCAL_DEMOD_PHASE': PCAL_LINE1_PCAL_DEMOD_PHASE,
-            'CAL-CS_TDEP_PCAL_LINE2_PCAL_DEMOD_PHASE': PCAL_LINE2_PCAL_DEMOD_PHASE,
-            'CAL-CS_TDEP_PCAL_LINE3_PCAL_DEMOD_PHASE': PCAL_LINE3_PCAL_DEMOD_PHASE,
-            'CAL-CS_TDEP_PCAL_LINE4_PCAL_DEMOD_PHASE': PCAL_LINE4_PCAL_DEMOD_PHASE,
             'CAL-CS_TDEP_SUS_LINE1_SUS_DEMOD_PHASE': SUS_LINE1_SUS_DEMOD_PHASE,
             'CAL-CS_TDEP_SUS_LINE2_SUS_DEMOD_PHASE': SUS_LINE2_SUS_DEMOD_PHASE,
             'CAL-CS_TDEP_SUS_LINE3_SUS_DEMOD_PHASE': SUS_LINE3_SUS_DEMOD_PHASE,
@@ -503,6 +440,48 @@ class DARMModel(Model):
                     if abs(ratio[0] - 1) > 0.000001:
                         print('Eeeeek! We had an EPICS connection error on '+chan+'. Check it!!')
 
+    def compute_etas(self, frequencies, sensing_syserr=None,
+                     actuation_syserr_dict=None):
+        """
+        Compute multiplicative scaling factor to the response function.
+        This returns "eta_R_C", applying sensing systematic error only;
+        "eta_R_A", applying actuation systematic error only; and "eta_R",
+        applying both sensing and systematic errors.
+
+        Parameters
+        ----------
+        frequencies : `float`, array-like
+            array of frequencies to compute the response
+        sensing_syserr : `complex`, array-like, optional
+            multiplicative factor to include relative sensing systematic error
+        actuation_syserr_dict : `dict`, optional
+            dict of multiplicative values, ex.:
+            {'xarm': {'UIM': `complex`, array-like},
+             'yarm': {'PUM': `complex`, array-like}}
+
+        Returns
+        -------
+        eta_R_c : `complex128`, array-like
+            multiplicative scaling factor for the response function, applying the
+            sensing systematic errors only
+        eta_R_a : `complex128`, array-like
+            multiplicative scaling factor for the response function, applying the
+            actuation systematic errors only
+        eta_R : `complex128`, array-like
+            multiplicative scaling factor for the response function, applying both
+            sensing and actuation systematic errors
+
+        """
+
+        R = self.compute_response_function(frequencies)
+
+        eta_R_c = self.compute_response_function(frequencies, sensing_syserr=sensing_syserr) / R
+        eta_R_a = self.compute_response_function(frequencies,
+                                                 actuation_syserr_dict=actuation_syserr_dict) / R
+        eta_R = self.compute_response_function(frequencies, sensing_syserr=sensing_syserr,
+                                               actuation_syserr_dict=actuation_syserr_dict) / R
+        return eta_R_c, eta_R_a, eta_R
+
     def plot(self, plot_selection='all', freq_min=0.1, freq_max=5000, filename=None, ifo='',
              label=None, style=None, ugf_start=10, ugf_end=1000, show=None, **kwargs):
         """
