@@ -859,11 +859,14 @@ class ProcessSensingMeasurement(ProcessMeasurement):
             np.random.normal([max_sensing_mag, 400.0],
                              [0.3*max_sensing_mag, 0.1*400.0],
                              size=(nwalkers, 2)),
-            np.random.uniform([1., 0.01, -61.], [10., 0.05, 61.],
+            np.random.uniform([1., 0.01, -61.e-6], [10., 0.05, 61.e-6],
                               size=(nwalkers, 3))))
 
         chain = self._mcmc(xdata, ydata, yerr, priors, **kwargs)
 
+        # Fix 1/Q ==> Q
+        chain[:, 3] = 1/chain[:, 3]
+
         if save_to_file is not None:
             self.save_results_to_json(
                 save_to_file, fmin, fmax, np.median(chain, axis=0), self.meas_type)
@@ -892,18 +895,18 @@ class ProcessSensingMeasurement(ProcessMeasurement):
             # fs for FOTON is abs(1/(2*pi*i)*s') where s' are the two solutions
             # to the quadratic formula - see alog LHO 31693
             fs1 = (1.0/(2.0*np.pi) *
-                   (-2.0*np.pi*MAP_values[2]*MAP_values[3]/2.0 +
-                    0.5*np.sqrt((2.0*np.pi*MAP_values[2]*MAP_values[3])**2 +
+                   (-2.0*np.pi*MAP_values[2]/MAP_values[3]/2.0 +
+                    0.5*np.sqrt((2.0*np.pi*MAP_values[2]/MAP_values[3])**2 +
                                 4.0*(2.0*np.pi*MAP_values[2])**2)))
             fs2 = (1.0/(2.0*np.pi) *
-                   (-2.0*np.pi*MAP_values[2]*MAP_values[3]/2.0 -
-                    0.5*np.sqrt((2.0*np.pi*MAP_values[2]*MAP_values[3])**2 +
+                   (-2.0*np.pi*MAP_values[2]/MAP_values[3]/2.0 -
+                    0.5*np.sqrt((2.0*np.pi*MAP_values[2]/MAP_values[3])**2 +
                                 4.0*(2.0*np.pi*MAP_values[2])**2)))
         else:
             # Take s^2/(s^2 - s0^2 + i*s*s0/Q) and solve denominator for zeros
-            Real = MAP_values[2]/2.0*MAP_values[3]
-            Imag = (MAP_values[2]/2.0*MAP_values[3] *
-                    np.sqrt(4.0/MAP_values[3]**2-1))
+            Real = MAP_values[2]/2.0/MAP_values[3]
+            Imag = (MAP_values[2]/2.0/MAP_values[3] *
+                    np.sqrt(4.0*MAP_values[3]**2-1))
             fs1 = Real + Imag*1j
             fs2 = Real - Imag*1j
 
@@ -1037,9 +1040,9 @@ class ProcessSensingMeasurement(ProcessMeasurement):
             # because we'll let the GPR take care of covering any variations
             # due to a potentially poorly modeled optical spring
             this_response_zpk = SensingModel.optical_response(
-                this_map[1], ref_map[2], 1/ref_map[3], this_spring)
+                this_map[1], ref_map[2], ref_map[3], this_spring)
             ref_response_zpk = SensingModel.optical_response(
-                ref_map[1], ref_map[2], 1/ref_map[3], this_spring)
+                ref_map[1], ref_map[2], ref_map[3], this_spring)
 
             this_model = this_map[0] * freqresp(
                 this_response_zpk, 2.0*np.pi*this_freq)[1]
@@ -1106,7 +1109,7 @@ class ProcessSensingMeasurement(ProcessMeasurement):
         for idx, _ in enumerate(stacked_meas):
             opticalResponse_ref_tf = MAP[0] * \
                signal.freqresp(SensingModel.optical_response(MAP[1], MAP[2],
-                                                             1/MAP[3]),
+                                                             MAP[3]),
                                2.0*np.pi*stacked_meas[idx][0])[1]
             if idx == 0:
                 residuals = np.array(
@@ -1291,7 +1294,7 @@ class ProcessActuationMeasurement(ProcessMeasurement):
         priors = np.hstack((
             np.random.normal(mean_actuation_mag, 0.3*mean_actuation_mag,
                              size=(nwalkers, 1)),
-            np.random.uniform(-61., 61., size=(nwalkers, 1))))
+            np.random.uniform(-61.e-6, 61.e-6, size=(nwalkers, 1))))
 
         chain = self._mcmc(xdata, ydata, yerr, priors, **kwargs)
 
@@ -1462,13 +1465,13 @@ def _ln_prob(pars):
                                                            1/pars[3],
                                                            is_pro_spring_gl),
                              2.0*np.pi*xdata_gl)[1] *
-                         np.exp(-2.*np.pi*1j*pars[4]*1e-6 * xdata_gl))
+                         np.exp(-2.*np.pi*1j*pars[4] * xdata_gl))
     elif (meas_type_gl == 'actuation_x_arm'
           or meas_type_gl == 'actuation_y_arm'):
         if pars[0] <= 0.0:
             return -np.inf
         this_response = (pars[0] *
-                         np.exp(-2.*np.pi*1j*pars[1]*1e-6 * xdata_gl))
+                         np.exp(-2.*np.pi*1j*pars[1] * xdata_gl))
     return np.sum(_log_norm_pdf(ydata_gl, this_response, yerr_gl))
 
 
