@@ -90,6 +90,24 @@ class SensingModel(Model):
         coupled_cavity = serielZPK(cavity_pole, detuning)
         return coupled_cavity
 
+    def mean_arm_length(self):
+        """
+        Compute the mean arm length of the x and y arms
+
+        Parameters
+        ----------
+
+        Returns
+        -------
+        mean_length : `float`
+            mean arm length in units of meters
+        """
+
+        mean_length = np.mean(
+            np.array([self.x_arm_length, self.y_arm_length]))
+
+        return mean_length
+
     def omc_dcpd_transimpedence_amplifier_response(self, name, frequencies):
         """
         The transfer function of the analog OMC DCPD transimpedence amplifier
@@ -411,8 +429,7 @@ class SensingModel(Model):
         """
 
         return np.exp(-2.0*np.pi*1j *
-                      np.mean(np.array([self.x_arm_length,
-                                        self.y_arm_length])) /
+                      self.mean_arm_length() /
                       constants.c * frequencies)
 
     def single_pole_approximation_delay_correction_response(self, frequencies):
