@@ -216,7 +216,7 @@ class Testcheck_td_vs_fd(unittest.TestCase):
 
     def setUp(self):
         self.FIRPars = FIRfilter(fNyq=10, dur=1, highpass_fcut=10, lowpass_fcut=None,
-                                 latency=None, window_type='dpss', freq_res=3.0)
+                                 latency=None, window_type='hann', freq_res=3.0)
         self.config = '''
 [metadata]
 [interferometer]
@@ -285,7 +285,7 @@ class Testcheck_td_vs_fd_response(unittest.TestCase):
 
     def setUp(self):
         self.FIRPars = FIRfilter(fNyq=10, dur=1, highpass_fcut=10, lowpass_fcut=None,
-                                 latency=None, window_type='dpss', freq_res=3.0)
+                                 latency=None, window_type='hann', freq_res=3.0)
         self.config = '''
 [metadata]
 [interferometer]
@@ -725,8 +725,8 @@ class TestFilterGeneration(unittest.TestCase):
 class TestGDS(unittest.TestCase):
 
     def setUp(self):
-        self.GDS_file = np.load('./test/GDS_test.npz')
-        self.ctrl_corr_td = self.GDS_file['ctrl_corr_filter']
+        self.GDS_file = h5py.File('./test/GDS_test.h5', 'r')
+        self.ctrl_corr_td = self.GDS_file['ctrl_corr_filter'][:]
         os.environ['CAL_DATA_ROOT'] = './test'
 
     def tearDown(self):
@@ -750,8 +750,8 @@ class TestGDS(unittest.TestCase):
 class TestDCS(unittest.TestCase):
 
     def setUp(self):
-        self.DCS_file = np.load('./test/DCS_test.npz')
-        self.known_act_tst = self.DCS_file['actuation_tst']
+        self.DCS_file = h5py.File('./test/DCS_test.h5', 'r')
+        self.known_act_tst = self.DCS_file['actuation_tst'][:]
         os.environ['CAL_DATA_ROOT'] = './test'
 
     def tearDown(self):
