@@ -1054,24 +1054,7 @@ class TestComputeActuation(unittest.TestCase):
 
     def setUp(self):
         self.frequencies = np.logspace(0, np.log10(5000.), 10)
-        self.known_A = np.array(
-            [-3.63234851552863e-13-2.297849477733715e-13j,
-             -1.5785405207037768e-14+7.022803250131525e-15j,
-             -1.9906028977349535e-15+8.499087530441956e-16j,
-             -2.9626430309517743e-16+4.980882746237151e-17j,
-             -4.5497245018124926e-17+5.851368523167505e-18j,
-             -7.117215795049456e-18+7.70258488252587e-19j,
-             -9.974890659056889e-19+7.966180520139261e-19j,
-             3.8712043816670766e-20+1.8134804487474165e-19j,
-             -7.463095731015656e-21-2.67674977773168e-20j,
-             2.3885824821188465e-21-3.8665176935995385e-22j])
-
-    def tearDown(self):
-        del self.frequencies
-        del self.known_A
-
-    def test_computeActuation(self):
-        A = pydarm.actuation.DARMActuationModel('''
+        self.model_string = '''
 [metadata]
 [interferometer]
 [actuation_x_arm]
@@ -1127,21 +1110,8 @@ uim_drive_align_gain = 1.0
 darm_output_matrix = 1.0, -1.0, 0.0, 0.0
 darm_feedback_x = OFF, ON, ON, ON
 darm_feedback_y = OFF, OFF, OFF, OFF
-''')
-        actuation_tf = A.compute_actuation(self.frequencies)
-        for n in range(len(self.frequencies)):
-            self.assertAlmostEqual(np.abs(actuation_tf[n]),
-                                   np.abs(self.known_A[n]))
-            self.assertAlmostEqual(
-                np.angle(actuation_tf[n], deg=True),
-                np.angle(self.known_A[n], deg=True))
-
-
-class TestComputeMultiArmActuation(unittest.TestCase):
-
-    def setUp(self):
-        self.frequencies = np.logspace(0, np.log10(5000.), 10)
-        self.known_A = 2*np.array(
+'''
+        self.known_A = np.array(
             [-3.63234851552863e-13-2.297849477733715e-13j,
              -1.5785405207037768e-14+7.022803250131525e-15j,
              -1.9906028977349535e-15+8.499087530441956e-16j,
@@ -1155,10 +1125,35 @@ class TestComputeMultiArmActuation(unittest.TestCase):
 
     def tearDown(self):
         del self.frequencies
+        del self.model_string
         del self.known_A
 
-    def test_computeActuation(self):
-        A = pydarm.actuation.DARMActuationModel('''
+    def test_compute_actuation(self):
+        A = pydarm.actuation.DARMActuationModel(self.model_string)
+        actuation_tf = A.compute_actuation(self.frequencies)
+        for n in range(len(self.frequencies)):
+            self.assertAlmostEqual(np.abs(actuation_tf[n]),
+                                   np.abs(self.known_A[n]))
+            self.assertAlmostEqual(
+                np.angle(actuation_tf[n], deg=True),
+                np.angle(self.known_A[n], deg=True))
+
+    def test_arm_super_actuator(self):
+        A = pydarm.actuation.DARMActuationModel(self.model_string)
+        actuation_tf = A.arm_super_actuator(self.frequencies)
+        for n in range(len(self.frequencies)):
+            self.assertAlmostEqual(np.abs(actuation_tf[n]),
+                                   np.abs(self.known_A[n]))
+            self.assertAlmostEqual(
+                np.angle(actuation_tf[n], deg=True),
+                np.angle(self.known_A[n], deg=True))
+
+
+class TestComputeMultiArmActuation(unittest.TestCase):
+
+    def setUp(self):
+        self.frequencies = np.logspace(0, np.log10(5000.), 10)
+        self.model_string = '''
 [metadata]
 [interferometer]
 [actuation_x_arm]
@@ -1263,7 +1258,38 @@ uim_drive_align_gain = 1.0
 darm_output_matrix = 1.0, -1.0, 0.0, 0.0
 darm_feedback_x = OFF, ON, ON, ON
 darm_feedback_y = OFF, ON, ON, ON
-''')
+'''
+        self.known_A = 2*np.array(
+            [-3.63234851552863e-13-2.297849477733715e-13j,
+             -1.5785405207037768e-14+7.022803250131525e-15j,
+             -1.9906028977349535e-15+8.499087530441956e-16j,
+             -2.9626430309517743e-16+4.980882746237151e-17j,
+             -4.5497245018124926e-17+5.851368523167505e-18j,
+             -7.117215795049456e-18+7.70258488252587e-19j,
+             -9.974890659056889e-19+7.966180520139261e-19j,
+             3.8712043816670766e-20+1.8134804487474165e-19j,
+             -7.463095731015656e-21-2.67674977773168e-20j,
+             2.3885824821188465e-21-3.8665176935995385e-22j])
+        self.known_super_act = np.array(
+            [-4.4452584691383385e-15+7.411167179232215e-16j,
+             2.3536993809387682e-15+5.130116377710275e-16j,
+             6.236926239205679e-16-1.9884058495535515e-15j,
+             -2.388957355496579e-16-4.3441463078690887e-16j,
+             -1.0152362687187823e-16-4.6889936601361595e-17j,
+             -1.8538651825179792e-17+1.769718541540502e-18j,
+             -1.955189357592536e-18+1.5915885140228738e-18j,
+             7.665512735370611e-20+3.621744507461856e-19j,
+             -1.4601630153846298e-20-5.34526407669915e-20j,
+             4.777143021044974e-21-7.734375898626229e-22j])
+
+    def tearDown(self):
+        del self.frequencies
+        del self.model_string
+        del self.known_A
+        del self.known_super_act
+
+    def test_multi_actuation(self):
+        A = pydarm.actuation.DARMActuationModel(self.model_string)
         actuation_tf = A.compute_actuation(self.frequencies)
         for n in range(len(self.frequencies)):
             self.assertAlmostEqual(np.abs(actuation_tf[n]),
@@ -1272,6 +1298,16 @@ darm_feedback_y = OFF, ON, ON, ON
                 np.angle(actuation_tf[n], deg=True),
                 np.angle(self.known_A[n], deg=True))
 
+    def test_stage_super_actuator(self):
+        A = pydarm.actuation.DARMActuationModel(self.model_string)
+        actuation_tf = A.stage_super_actuator(self.frequencies)
+        for n in range(len(self.frequencies)):
+            self.assertAlmostEqual(np.abs(actuation_tf[n]),
+                                   np.abs(self.known_super_act[n]))
+            self.assertAlmostEqual(
+                np.angle(actuation_tf[n], deg=True),
+                np.angle(self.known_super_act[n], deg=True))
+
 
 if __name__ == '__main__':
     unittest.main()
