@@ -168,7 +168,6 @@ foton_invsensing_tf = \
             self.assertAlmostEqual(
                 np.angle(gds_corr[n], deg=True),
                 np.angle(self.known_gds_correction[n], deg=True))
-            # print(gds_corr[n])
     
     def test_C_corr(self):
         """ Test the computation of C_corr """
@@ -308,6 +307,119 @@ uim_NpA = 1.634
                                    np.angle(self.known_long_tst[n], deg=True))
 
 
+class TestStageSuperActuator(unittest.TestCase):
+
+    def setUp(self):
+        self.frequencies = np.logspace(0, np.log10(5000.), 10)
+        self.known_actuation = np.array(
+            [-5.310569188975287e-15+7.256951812950946e-16j,
+             2.373277011838796e-15+5.291008654481964e-16j,
+             6.565119740746598e-16-1.9982361183467982e-15j,
+             -2.2559506195176175e-16-4.466754954217274e-16j,
+             -9.777506975890007e-17-5.640474139960699e-17j,
+             -1.862001070553775e-17-2.5901317072945293e-18j,
+             -2.5387144596970953e-18+2.087430071154024e-19j,
+             -3.6579868747198944e-19+8.64886306967107e-20j,
+             -3.031250280475011e-20+4.8441976904940323e-20j,
+             -3.257386852647821e-21-2.3520741277934774e-21j])
+
+    def tearDown(self):
+        del self.frequencies
+
+    def test_stage_super_actuator(self):
+        calcs = pydarm.calcs.CALCSModel('''
+[metadata]
+[interferometer]
+[sensing]
+[digital]
+[actuation]
+darm_output_matrix = 1.0, -1.0, 0.0, 0.0
+darm_feedback_x = OFF, OFF, OFF, ON
+darm_feedback_y = OFF, OFF, OFF, ON
+[actuation_x_arm]
+darm_feedback_sign = -1
+tst_NpV2 = 4.427e-11
+linearization = OFF
+actuation_esd_bias_voltage = -9.3
+tst_driver_DC_gain_VpV_HV = 40
+tst_driver_DC_gain_VpV_LV = 1.881
+anti_imaging_rate_string = 16k
+anti_imaging_method = biquad
+analog_anti_imaging_file = test/H1aa.mat
+dac_gain = 7.62939453125e-05
+sus_filter_file = test/H1SUSETMX_1236641144.txt
+tst_isc_inf_bank = ETMX_L3_ISCINF_L
+tst_isc_inf_modules =
+tst_isc_inf_gain = 1.0
+tst_lock_bank = ETMX_L3_LOCK_L
+tst_lock_modules = 5,8,9,10
+tst_lock_gain = 1.0
+tst_drive_align_bank = ETMX_L3_DRIVEALIGN_L2L
+tst_drive_align_modules = 4,5
+tst_drive_align_gain = -35.7
+pum_lock_bank = ETMX_L2_LOCK_L
+pum_lock_modules = 7
+pum_lock_gain = 23.0
+pum_drive_align_bank = ETMX_L2_DRIVEALIGN_L2L
+pum_drive_align_modules = 6,7
+pum_drive_align_gain = 1.0
+uim_lock_bank = ETMX_L1_LOCK_L
+uim_lock_modules = 10
+uim_lock_gain = 1.06
+uim_drive_align_bank = ETMX_L1_DRIVEALIGN_L2L
+uim_drive_align_modules =
+uim_drive_align_gain = 1.0
+[actuation_y_arm]
+darm_feedback_sign = 1
+tst_NpV2 = 4.427e-11
+linearization = OFF
+actuation_esd_bias_voltage = -9.3
+tst_driver_DC_gain_VpV_HV = 40
+tst_driver_DC_gain_VpV_LV = 1.881
+anti_imaging_rate_string = 16k
+anti_imaging_method = biquad
+analog_anti_imaging_file = test/H1aa.mat
+dac_gain = 7.62939453125e-05
+sus_filter_file = test/H1SUSETMX_1236641144.txt
+tst_isc_inf_bank = ETMX_L3_ISCINF_L
+tst_isc_inf_modules =
+tst_isc_inf_gain = 1.0
+tst_lock_bank = ETMX_L3_LOCK_L
+tst_lock_modules = 5,8,9,10
+tst_lock_gain = 1.0
+tst_drive_align_bank = ETMX_L3_DRIVEALIGN_L2L
+tst_drive_align_modules = 4,5
+tst_drive_align_gain = -35.7
+pum_lock_bank = ETMX_L2_LOCK_L
+pum_lock_modules = 7
+pum_lock_gain = 23.0
+pum_drive_align_bank = ETMX_L2_DRIVEALIGN_L2L
+pum_drive_align_modules = 6,7
+pum_drive_align_gain = 1.0
+uim_lock_bank = ETMX_L1_LOCK_L
+uim_lock_modules = 10
+uim_lock_gain = 1.06
+uim_drive_align_bank = ETMX_L1_DRIVEALIGN_L2L
+uim_drive_align_modules =
+uim_drive_align_gain = 1.0
+[calcs]
+xarm_uim_analog = test/H1CALCS_ETMX_L1_ANALOG.txt
+xarm_pum_analog = test/H1CALCS_ETMX_L2_ANALOG.txt
+xarm_tst_analog = test/H1CALCS_ETMX_L3_ANALOG.txt
+xarm_output_matrix = 0.0, -1.0, -1.0, -1.0
+yarm_output_matrix = 0.0, -1.0, -1.0, -1.0
+yarm_uim_analog = test/H1CALCS_ETMX_L1_ANALOG.txt
+yarm_pum_analog = test/H1CALCS_ETMX_L2_ANALOG.txt
+yarm_tst_analog = test/H1CALCS_ETMX_L3_ANALOG.txt
+''')
+        test_val = calcs.stage_super_actuator(self.frequencies)
+        for n in range(len(self.frequencies)):
+            self.assertAlmostEqual(np.abs(test_val[n]) /
+                                   np.abs(self.known_actuation[n]), 1)
+            self.assertAlmostEqual(np.angle(test_val[n], deg=True),
+                                   np.angle(self.known_actuation[n], deg=True))
+
+
 class TestGdsActuationCorrection(unittest.TestCase):
 
     def setUp(self):
@@ -432,24 +544,7 @@ class TestCalcsDarmActuation(unittest.TestCase):
 
     def setUp(self):
         self.frequencies = np.logspace(0, np.log10(5000.), 10)
-        self.known_actuation = np.array(
-            [-4.517595087730189e-13-2.574036100879927e-13j,
-             -1.588361922503374e-14+6.321091918942617e-15j,
-             -2.010750482679724e-15+8.323452747346148e-16j,
-             -3.003908484149924e-16+4.0189540926990994e-17j,
-             -4.589254777634106e-17+1.7738463389039645e-18j,
-             -7.164372681090654e-18-9.924814855271752e-19j,
-             -1.2876117069737756e-18+9.59002289638503e-20j,
-             -1.8304199780422068e-19+4.3641229060862356e-20j,
-             -1.4943625550308623e-20+2.4185781589291237e-20j,
-             -1.6286934512050932e-21-1.176037151353447e-21j])
-
-    def tearDown(self):
-        del self.frequencies
-        del self.known_actuation
-
-    def test_calcs_darm_actuation(self):
-        calcs = pydarm.calcs.CALCSModel('''
+        self.model_string = '''
 [metadata]
 [interferometer]
 [sensing]
@@ -501,7 +596,26 @@ xarm_uim_analog = test/H1CALCS_ETMX_L1_ANALOG.txt
 xarm_pum_analog = test/H1CALCS_ETMX_L2_ANALOG.txt
 xarm_tst_analog = test/H1CALCS_ETMX_L3_ANALOG.txt
 xarm_output_matrix = 0.0, -1.0, -1.0, -1.0
-''')
+'''
+        self.known_actuation = np.array(
+            [-4.517595087730189e-13-2.574036100879927e-13j,
+             -1.588361922503374e-14+6.321091918942617e-15j,
+             -2.010750482679724e-15+8.323452747346148e-16j,
+             -3.003908484149924e-16+4.0189540926990994e-17j,
+             -4.589254777634106e-17+1.7738463389039645e-18j,
+             -7.164372681090654e-18-9.924814855271752e-19j,
+             -1.2876117069737756e-18+9.59002289638503e-20j,
+             -1.8304199780422068e-19+4.3641229060862356e-20j,
+             -1.4943625550308623e-20+2.4185781589291237e-20j,
+             -1.6286934512050932e-21-1.176037151353447e-21j])
+
+    def tearDown(self):
+        del self.frequencies
+        del self.model_string
+        del self.known_actuation
+
+    def test_calcs_darm_actuation(self):
+        calcs = pydarm.calcs.CALCSModel(self.model_string)
         test_actuation = calcs.calcs_darm_actuation(self.frequencies)
         for n in range(len(self.frequencies)):
             self.assertAlmostEqual(
@@ -511,6 +625,17 @@ xarm_output_matrix = 0.0, -1.0, -1.0, -1.0
                 np.angle(test_actuation[n], deg=True),
                 np.angle(self.known_actuation[n], deg=True))
 
+    def test_arm_super_actuator(self):
+        calcs = pydarm.calcs.CALCSModel(self.model_string)
+        test_actuation = calcs.arm_super_actuator(self.frequencies)
+        for n in range(len(self.frequencies)):
+            self.assertAlmostEqual(
+                np.abs((test_actuation[n]) /
+                        np.abs(self.known_actuation[n])), 1)
+            self.assertAlmostEqual(
+                np.angle(test_actuation[n], deg=True),
+                np.angle(self.known_actuation[n], deg=True))
+
 
 class TestACorr(unittest.TestCase):
 
@@ -773,24 +898,7 @@ class TestCalcsDttCalibration(unittest.TestCase):
     def setUp(self):
         # Pre-computed values
         self.frequencies = np.logspace(0, np.log10(5000.), 10)
-        self.known_dtt_calibration = np.array(
-            [0.00019356005813191712-0.00042488196251998944j,
-             -9.451078100284736e-07-2.284431871622057e-06j,
-             1.7790453057980935e-10-9.716717778553878e-09j,
-             6.612312986720728e-11+6.670843982848847e-12j,
-             -3.0625580407492805e-12+9.707481479785013e-13j,
-             1.7153848960220716e-13-1.254844015881104e-12j,
-             9.785864383613003e-13-2.354168502599546e-13j,
-             7.738102950993615e-13+6.274479982018254e-13j,
-             -6.479370603503953e-13+7.062109756021947e-13j,
-             8.255633601165232e-13+3.1898890750452897e-13j])
-
-    def tearDown(self):
-        del self.frequencies
-        del self.known_dtt_calibration
-
-    def test_calcs_dtt_calibration(self):
-        calcs = pydarm.calcs.CALCSModel('''
+        self.model_string = '''
 [metadata]
 [interferometer]
 [sensing]
@@ -875,6 +983,12 @@ uim_lock_gain = 1.06
 uim_drive_align_bank = ETMX_L1_DRIVEALIGN_L2L
 uim_drive_align_modules =
 uim_drive_align_gain = 1.0
+[pcal]
+pcal_dewhiten = 1.0, 1.0
+ref_pcal_2_darm_act_sign = -1
+analog_anti_aliasing_file = test/H1aa.mat
+anti_aliasing_rate_string = 16k
+anti_aliasing_method = biquad
 [calcs]
 foton_invsensing_tf = \
   test/2019-04-04_H1CALCS_InverseSensingFunction_Foton_SRCD-2N_Gain_tf.txt
@@ -885,8 +999,38 @@ xarm_pum_analog = test/H1CALCS_ETMX_L2_ANALOG.txt
 xarm_tst_analog = test/H1CALCS_ETMX_L3_ANALOG.txt
 xarm_output_matrix = 0.0, -1.0, -1.0, -1.0
 foton_delay_filter_tf = test/H1CALCS_8_CLK_DELAY.txt
-''')
+'''
+        self.known_dtt_calibration = np.array(
+            [0.00019356005813191712-0.00042488196251998944j,
+             -9.451078100284736e-07-2.284431871622057e-06j,
+             1.7790453057980935e-10-9.716717778553878e-09j,
+             6.612312986720728e-11+6.670843982848847e-12j,
+             -3.0625580407492805e-12+9.707481479785013e-13j,
+             1.7153848960220716e-13-1.254844015881104e-12j,
+             9.785864383613003e-13-2.354168502599546e-13j,
+             7.738102950993615e-13+6.274479982018254e-13j,
+             -6.479370603503953e-13+7.062109756021947e-13j,
+             8.255633601165232e-13+3.1898890750452897e-13j])
+        self.known_correction = np.array(
+            [0.08050209475040816-1.6513476841862913j,
+             5.520955244198903-5.39432597631647j,
+             42.86576723694163-12.95206706562494j,
+             286.2976701235751-29.870138626022648j,
+             1989.2449225789353+25.625179916953805j,
+             13324.518167327555-256.1410730974964j,
+             83043.27111119543+8600.650901100558j,
+             550117.5295480754+134754.87628064284j,
+             3020136.055721985+2211463.562530411j,
+             -2232612.4359687367+21856221.21387424j])
 
+    def tearDown(self):
+        del self.frequencies
+        del self.model_string
+        del self.known_dtt_calibration
+        del self.known_correction
+
+    def test_calcs_dtt_calibration(self):
+        calcs = pydarm.calcs.CALCSModel(self.model_string)
         calcs_dtt_calib = calcs.calcs_dtt_calibration(self.frequencies)
         for n in range(len(self.frequencies)):
             self.assertAlmostEqual(
@@ -896,6 +1040,17 @@ foton_delay_filter_tf = test/H1CALCS_8_CLK_DELAY.txt
                 np.angle(calcs_dtt_calib[n], deg=True),
                 np.angle(self.known_dtt_calibration[n], deg=True))
 
+    def test_deltal_ext_pcal_corrrection(self):
+        calcs = pydarm.calcs.CALCSModel(self.model_string)
+        deltal_ext_pcal = calcs.deltal_ext_pcal_corrrection(self.frequencies)
+        for n in range(len(self.frequencies)):
+            self.assertAlmostEqual(
+                np.abs(deltal_ext_pcal[n] /
+                       np.abs(self.known_correction[n])), 1)
+            self.assertAlmostEqual(
+                np.angle(deltal_ext_pcal[n], deg=True),
+                np.angle(self.known_correction[n], deg=True))
+
 
 if __name__ == '__main__':
     unittest.main()
