@@ -292,7 +292,7 @@ class TestComputeEpicsRecords(unittest.TestCase):
 
     def setUp(self):
         self.frequencies = np.array(
-            [17.1, 15.6, 16.4, 17.6, 410.3, 1083.7, 7.93])
+            [17.1, 15.6, 16.4, 17.6, 410.3, 1083.7])
         self.known_epics = {
             'CAL-CS_TDEP_PCAL_LINE1_CORRECTION':
             0.003384106838174459+0.0004044180029064908j,
@@ -314,18 +314,6 @@ class TestComputeEpicsRecords(unittest.TestCase):
             9.669640696236252e-23+1.0084874176645285e-22j,
             'CAL-CS_TDEP_PCAL_LINE2_CORRECTION':
             5.919275925544666e-06+3.317567316630787e-07j,
-            'CAL-CS_TDEP_PCAL_LINE4_REF_C_NOCAVPOLE':
-            3219939.105380994-20248.45691682977j,
-            'CAL-CS_TDEP_PCAL_LINE4_REF_D':
-            -1334010103.6339288-1921974046.2409313j,
-            'CAL-CS_TDEP_PCAL_LINE4_REF_A_TST':
-            3.868595124883083e-17-7.793733735356113e-16j,
-            'CAL-CS_TDEP_PCAL_LINE4_REF_A_PUM':
-            -1.6867571291492549e-15+9.32181952713231e-16j,
-            'CAL-CS_TDEP_PCAL_LINE4_REF_A_UIM':
-            2.420118862241151e-16+3.3925102853622382e-16j,
-            'CAL-CS_TDEP_PCAL_LINE4_CORRECTION':
-            0.015159268559718102+0.003900900009459194j,
             'CAL-CS_TDEP_PCAL_LINE1_REF_C_NOCAVPOLE':
             3219708.6791652623-43662.16666949552j,
             'CAL-CS_TDEP_PCAL_LINE1_REF_D':
@@ -338,10 +326,6 @@ class TestComputeEpicsRecords(unittest.TestCase):
             4.078008711853952e-17+4.992745126138772e-18j,
             'CAL-CS_TDEP_PCAL_LINE3_CORRECTION':
             8.319363469674813e-07+1.1949591405958398e-07j,
-            'CAL-CS_TDEP_PCAL_LINE1_PCAL_DEMOD_PHASE': -0.37573242187500006,
-            'CAL-CS_TDEP_PCAL_LINE2_PCAL_DEMOD_PHASE': -9.015380859375002,
-            'CAL-CS_TDEP_PCAL_LINE3_PCAL_DEMOD_PHASE': -23.811767578125,
-            'CAL-CS_TDEP_PCAL_LINE4_PCAL_DEMOD_PHASE': -0.17424316406249998,
             'CAL-CS_TDEP_SUS_LINE1_SUS_DEMOD_PHASE': -0.3427734375,
             'CAL-CS_TDEP_SUS_LINE2_SUS_DEMOD_PHASE': -0.36035156249999994,
             'CAL-CS_TDEP_SUS_LINE3_SUS_DEMOD_PHASE': -0.38671875}
@@ -447,7 +431,7 @@ digital_filter_gain = 400,1
         test_epics = darm.compute_epics_records(
             self.frequencies[0], self.frequencies[1], self.frequencies[2],
             self.frequencies[3], self.frequencies[4], self.frequencies[5],
-            self.frequencies[6], arm='x', endstation=True)
+            arm='x', endstation=True)
         for idx, (key, val) in enumerate(self.known_epics.items()):
             self.assertAlmostEqual(
                 np.abs(test_epics[key]/self.known_epics[key]), 1.0, places=6)
@@ -456,5 +440,149 @@ digital_filter_gain = 400,1
                 np.angle(self.known_epics[key], deg=True), 0.0, places=5)
 
 
+class TestComputeEtas(unittest.TestCase):
+
+    def setUp(self):
+        self.frequencies = np.logspace(np.log10(20), np.log10(2000), 10)
+        self.syserr_input = np.array(
+            [1.0000003831992847-0.0007929858798234665j,
+             0.9999986255804106-0.002042969515282433j,
+             0.9999869597043107-0.0052632862823899385j,
+             0.9999095302557972-0.013559488366496989j,
+             0.9993956411093269-0.03492779907418393j,
+             0.995986356934377-0.08988999137528689j,
+             0.9734269429695694-0.22996802633705743j,
+             0.8267642616923517-0.5649608162253222j,
+             -0.004181642663901519-1.003311656263212j,
+             -0.19691508479464048+0.7796521952236531j])
+        self.known_etas = np.array(
+            [[0.99997492-4.43808402e-04j, 0.99816941-1.32625955e-03j,
+              0.99042173+2.75217421e-03j, 0.98764461+2.40563425e-02j,
+              1.00478583+5.90395517e-02j, 1.01828258+8.71417774e-02j,
+              0.94939253+2.12468056e-01j, 0.82362819+5.75180328e-01j,
+              -0.00435558+9.98282271e-01j, -0.30462374-1.20565509e+00j],
+             [1.-0.00000000e+00j, 1.-0.00000000e+00j,
+              1.-0.00000000e+00j, 1.+0.00000000e+00j,
+              1.+0.00000000e+00j, 1.-6.08247505e-17j,
+              1.+0.00000000e+00j, 1.+0.00000000e+00j,
+              1.+0.00000000e+00j, 1.-0.00000000e+00j],
+             [0.99997492-4.43808402e-04j, 0.99816941-1.32625955e-03j,
+              0.99042173+2.75217421e-03j, 0.98764461+2.40563425e-02j,
+              1.00478583+5.90395517e-02j, 1.01828258+8.71417774e-02j,
+              0.94939253+2.12468056e-01j, 0.82362819+5.75180328e-01j,
+              -0.00435558+9.98282271e-01j, -0.30462374-1.20565509e+00j]])
+
+    def tearDown(self):
+        del self.frequencies
+        del self.syserr_input
+        del self.known_etas
+
+    def test_compute_etas(self):
+        model_string = '''
+[metadata]
+[interferometer]
+[sensing]
+x_arm_length = 3994.4704
+y_arm_length = 3994.4692
+coupled_cavity_optical_gain = 3.22e6
+coupled_cavity_pole_frequency = 410.6
+detuned_spring_frequency = 4.468
+detuned_spring_Q = 52.14
+sensing_sign = 1
+is_pro_spring = True
+anti_aliasing_rate_string = 16k
+anti_aliasing_method      = biquad
+analog_anti_aliasing_file = test/H1aa.mat, test/H1aa.mat
+omc_meas_p_trans_amplifier   = 13.7e3, 17.8e3: 13.7e3, 17.8e3
+whitening_mode_names = test, test
+omc_meas_p_whitening_test   = 11.346e3, 32.875e3, 32.875e3: 11.521e3, 32.863e3, 32.863e3
+super_high_frequency_poles_apparent_delay = 0, 0
+gain_ratio = 1, 1
+balance_matrix = 1, 1
+omc_path_names = A, B
+single_pole_approximation_delay_correction = -12e-6
+adc_gain = 1, 1
+
+[actuation_x_arm]
+darm_feedback_sign = -1
+tst_NpV2 = 4.427e-11
+linearization = OFF
+actuation_esd_bias_voltage = -9.3
+suspension_file = test/H1susdata_O3.mat
+tst_driver_meas_Z_UL = 129.7e3
+tst_driver_meas_Z_LL = 90.74e3
+tst_driver_meas_Z_UR = 93.52e3
+tst_driver_meas_Z_LR = 131.5e3
+tst_driver_meas_P_UL = 3.213e3, 31.5e3
+tst_driver_meas_P_LL = 3.177e3, 26.7e3
+tst_driver_meas_P_UR = 3.279e3, 26.6e3
+tst_driver_meas_P_LR = 3.238e3, 31.6e3
+tst_driver_DC_gain_VpV_HV = 40
+tst_driver_DC_gain_VpV_LV = 1.881
+anti_imaging_rate_string = 16k
+anti_imaging_method = biquad
+analog_anti_imaging_file = test/H1aa.mat
+dac_gain = 7.62939453125e-05
+unknown_actuation_delay = 15e-6
+pum_driver_DC_trans_ApV = 2.6847e-4
+pum_coil_outf_signflip = 1
+pum_NpA = 0.02947
+uim_driver_DC_trans_ApV = 6.1535e-4
+uim_NpA = 1.634
+sus_filter_file = test/H1SUSETMX_1236641144.txt
+tst_isc_inf_bank = ETMX_L3_ISCINF_L
+tst_isc_inf_modules =
+tst_isc_inf_gain = 1.0
+tst_lock_bank = ETMX_L3_LOCK_L
+tst_lock_modules = 5,8,9,10
+tst_lock_gain = 1.0
+tst_drive_align_bank = ETMX_L3_DRIVEALIGN_L2L
+tst_drive_align_modules = 4,5
+tst_drive_align_gain = -35.7
+pum_lock_bank = ETMX_L2_LOCK_L
+pum_lock_modules = 7
+pum_lock_gain = 23.0
+pum_drive_align_bank = ETMX_L2_DRIVEALIGN_L2L
+pum_drive_align_modules = 6,7
+pum_drive_align_gain = 1.0
+uim_lock_bank = ETMX_L1_LOCK_L
+uim_lock_modules = 10
+uim_lock_gain = 1.06
+uim_drive_align_bank = ETMX_L1_DRIVEALIGN_L2L
+uim_drive_align_modules =
+uim_drive_align_gain = 1.0
+
+[actuation]
+darm_output_matrix = 1.0, -1.0, 0.0, 0.0
+darm_feedback_x = OFF, ON, ON, ON
+darm_feedback_y = OFF, OFF, OFF, OFF
+
+[digital]
+digital_filter_file = test/H1OMC_1239468752.txt
+digital_filter_bank = LSC_DARM1, LSC_DARM2
+digital_filter_modules_in_use = 1,2,3,4,7,9,10: 3,4,5,6,7
+digital_filter_gain = 400,1
+'''
+        darm = pydarm.darm.DARMModel(model_string)
+        test_eta_R_c, test_eta_R_a, test_eta_R = \
+            darm.compute_etas(self.frequencies, sensing_syserr=self.syserr_input)
+        for n in range(len(self.frequencies)):
+            self.assertAlmostEqual(
+                np.abs(test_eta_R_c[n]) / np.abs(self.known_etas[0][n]), 1.0)
+            self.assertAlmostEqual(
+                np.angle(test_eta_R_c[n], deg=True) -
+                np.angle(self.known_etas[0][n], deg=True), 0.0, places=5)
+            self.assertAlmostEqual(
+                np.abs(test_eta_R_a[n]) / np.abs(self.known_etas[1][n]), 1.0)
+            self.assertAlmostEqual(
+                np.angle(test_eta_R_a[n], deg=True) -
+                np.angle(self.known_etas[1][n], deg=True), 0.0, places=5)
+            self.assertAlmostEqual(
+                np.abs(test_eta_R[n]) / np.abs(self.known_etas[2][n]), 1.0)
+            self.assertAlmostEqual(
+                np.angle(test_eta_R[n], deg=True) -
+                np.angle(self.known_etas[2][n], deg=True), 0.0, places=5)
+
+
 if __name__ == '__main__':
     unittest.main()
