@@ -467,10 +467,10 @@ anti_aliasing_method      = biquad
             ('H1:CAL-PCALY_RX_PD_OUT_DQ', 'H1:LSC-DARM_IN1_DQ'),
             meas1_cohThresh=0.90, meas2_cohThresh=0.992)
         self.known_optical_pars = np.array(
-            [3.14e6, 408.2, 0.2, 0.6, -2.4])
+            [3.14e6, 408.2, 0.2, 1.6666667, -2.4e-6])
         self.known_std = np.array(
-            [1.31938561e+03, 6.27393687e-01, 1.20974870e-01, 2.22589748e-01,
-             3.63299973e-01])
+            [1.31938561e+03, 6.27393687e-01, 1.20974870e-01, 1.9841479726420748,
+             3.63299973e-7])
 
     def tearDown(self):
         del self.meas
@@ -498,7 +498,7 @@ anti_aliasing_method      = biquad
         self.assertAlmostEqual(std_vals[0] / self.known_std[0], 1.0, places=1)
         self.assertAlmostEqual(std_vals[1] / self.known_std[1], 1.0, places=1)
         self.assertAlmostEqual(std_vals[2] / self.known_std[2], 1.0, places=1)
-        self.assertAlmostEqual(std_vals[3] / self.known_std[3], 1.0, places=1)
+        self.assertAlmostEqual(std_vals[3] / self.known_std[3], 1.0, places=0)
         self.assertAlmostEqual(std_vals[4] / self.known_std[4], 1.0, places=1)
 
 
@@ -578,7 +578,7 @@ anti_aliasing_method      = biquad
             ('H1:CAL-PCALY_RX_PD_OUT_DQ', 'H1:LSC-DARM_IN1_DQ'),
             meas1_cohThresh=0.90, meas2_cohThresh=0.992)
 
-        self.median_vals = np.atleast_2d(np.array([3.e6, 430., 1., 1/10., -1.]))
+        self.median_vals = np.atleast_2d(np.array([3.e6, 430., 1., 10., -1e-6]))
 
     def tearDown(self):
         del self.meas
@@ -614,7 +614,7 @@ class TestSensingSaveResultsToJson(unittest.TestCase):
         self.fmin = None
         self.fmax = None
         self.mcmc_map_vals = np.atleast_2d(
-            np.array([3.e6, 430., 1., 1/10., -1.]))
+            np.array([3.e6, 430., 1., 0.1, -1.e-6]))
 
     def tearDown(self):
         del self.filename
@@ -688,8 +688,8 @@ anti_aliasing_method      = biquad
         self.known_vals = np.asarray([3170611.467085059,
                                       408.1817342117136,
                                       0.19227856654546951,
-                                      0.6197211439122837,
-                                      -2.3711268610322085])
+                                      1.6136289842993343,
+                                      -2.3711268610322085e-6])
         self.known_is_pro_spring = False
 
     def tearDown(self):
@@ -1412,8 +1412,8 @@ anti_aliasing_method      = biquad
             ('H1:CAL-PCALY_RX_PD_OUT_DQ', 'H1:LSC-DARM_IN1_DQ'),
             meas1_cohThresh=0.9, meas2_cohThresh=0.9)
 
-        self.known_map_vals = np.array([4.41748043e-11, 7.55158561e+00])
-        self.known_std = np.array([9.33932576e-15, 5.12740323e-01])
+        self.known_map_vals = np.array([4.41748043e-11, 7.55158561e-6])
+        self.known_std = np.array([9.33932576e-15, 5.12740323e-07])
 
     def tearDown(self):
         del self.meas
