@@ -43,6 +43,29 @@ class TestOpticalResponse(unittest.TestCase):
                 np.angle(self.known_optical_response[n], deg=True))
 
 
+class TestMeanArmLength(unittest.TestCase):
+
+    def setUp(self):
+        # computed from
+        # x_arm_length = 3994.4704
+        # y_arm_length = 3994.4692
+        self.known_mean = 3994.4698
+
+    def tearDown(self):
+        del self.known_mean
+
+    def test_mean_arm_length(self):
+         C = pydarm.sensing.SensingModel('''
+[metadata]
+[interferometer]
+[sensing]
+x_arm_length = 3994.4704
+y_arm_length = 3994.4692
+''')
+         test_mean = C.mean_arm_length()
+         self.assertAlmostEqual(test_mean, self.known_mean)
+
+
 class TestOMCDCPDTransimpedenceAmplifierResponse(unittest.TestCase):
 
     def setUp(self):
